==> 3.5.12-core.tar: kdenetwork/krfb/srvloc/kinetinterfacewatcher.cpp <==
/*
 *  Watches Inet interfaces
 *  Copyright (C) 2002 Tim Jansen <tim@tjansen.de>
 *
 *  $Id: kinetinterfacewatcher.cpp 1157648 2010-07-31 19:48:06Z tpearson $
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "kinetinterfacewatcher.h"
#include "kinetinterfacewatcher.moc"

class KInetInterfaceWatcherPrivate {
public:
	TQString interface;
	int minInterval; // not used yet, but my be when a daemon watches


	KInetInterfaceWatcherPrivate(const TQString &iface,
				     int minIntv) :
		interface(iface),
		minInterval(minIntv) {
	}
};

/*
   * or all network interfaces.
   * @param interface the name of the interface to watch (e.g.'eth0')
   *                  or TQString::null to watch all interfaces
   * @param minInterval the minimum interval between two checks in
   *                    seconds. Be careful not to check too often, to
   *                    avoid unneccessary wasting of CPU time
   */
KInetInterfaceWatcher::KInetInterfaceWatcher(const TQString &interface,
					     int minInterval) {
	d = new KInetInterfaceWatcherPrivate(interface, minInterval);
}

TQString KInetInterfaceWatcher::interface() const {
	return d->interface;
}

KInetInterfaceWatcher::~KInetInterfaceWatcher() {
	delete d;
}

==> 3.5.13-core.tar: kdenetwork/krfb/srvloc/kinetinterfacewatcher.cpp <==
/*
 *  Watches Inet interfaces
 *  Copyright (C) 2002 Tim Jansen <tim@tjansen.de>
 *
 *  $Id: kinetinterfacewatcher.cpp 1237912 2011-06-22 00:30:31Z tpearson $
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "kinetinterfacewatcher.h"
#include "kinetinterfacewatcher.moc"

class KInetInterfaceWatcherPrivate {
public:
	TQString interface;
	int minInterval; // not used yet, but my be when a daemon watches


	KInetInterfaceWatcherPrivate(const TQString &iface,
				     int minIntv) :
		interface(iface),
		minInterval(minIntv) {
	}
};

/*
   * or all network interfaces.
   * @param interface the name of the interface to watch (e.g.'eth0')
   *                  or TQString() to watch all interfaces
   * @param minInterval the minimum interval between two checks in
   *                    seconds. Be careful not to check too often, to
   *                    avoid unneccessary wasting of CPU time
   */
KInetInterfaceWatcher::KInetInterfaceWatcher(const TQString &interface,
					     int minInterval) {
	d = new KInetInterfaceWatcherPrivate(interface, minInterval);
}

TQString KInetInterfaceWatcher::interface() const {
	return d->interface;
}

KInetInterfaceWatcher::~KInetInterfaceWatcher() {
	delete d;
}
